﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Reflection;
using System.Diagnostics;
using PGT.Common;

namespace PGT.ConfigurationManager
{
  public partial class ConfigPuller : Form
  {
    #region Fields
    /// <summary>
    /// The ID of the configuration set beeing deployed
    /// </summary>
    private int _configurationSetID;
    private BackgroundWorker _workInProgress;
    private string _workInProgressText = "Work in progress...";
    private string _workInProgressCaption = "Please be patient";
    private bool _workInProgress_CancelPressed = false;
    private bool _workInProgressSupportCancellation = false;
    private SqlCommand _workInProgressSqlCommandToCancel = null;
    /// <summary>
    /// The list of ScriptManagers of opened Scripting Forms
    /// </summary>
    private Hashtable ScriptManagers = new Hashtable();
    #endregion

    #region Initialization
    public ConfigPuller(int ConfigurationSetID)
    {
      InitializeComponent();
      _workInProgress = new BackgroundWorker();
      _workInProgress.DoWork += DoWorkAnimation;
      _workInProgress.WorkerSupportsCancellation = true;
      SetControlBackGround(this);
      _configurationSetID = ConfigurationSetID;
      ScriptManagers = new Hashtable();
    }
    private void SetControlBackGround(Control rootControl)
    {
      if (rootControl != null)
      {
        foreach (Control thisControl in rootControl.Controls)
        {
          if (thisControl is System.Windows.Forms.Label || thisControl is CheckBox || thisControl is GroupBox)
          {
            thisControl.BackColor = System.Drawing.Color.Transparent;
            MethodInfo m = thisControl.GetType().GetMethod("SetStyle");
            if (m != null) m.Invoke(thisControl, new object[] { ControlStyles.SupportsTransparentBackColor, true });
          }
          SetControlBackGround(thisControl);
        }
      }

    }
    private void DrawGradientBackground(object sender, PaintEventArgs e)
    {
      Rectangle rect = (sender as Control).ClientRectangle;
      using (Brush br = new LinearGradientBrush(rect, System.Drawing.Color.White, (sender as Control).BackColor, LinearGradientMode.Vertical))
      {
        e.Graphics.FillRectangle(br, rect);
      }
    }
    private void ConfigPuller_Load(object sender, EventArgs e)
    {
      setTargetsTA.FillTargetsInSet(configDS.SetTargets, _configurationSetID);
      if (configDS.SetTargets.Rows.Count > 0)
      {
        tbSelConfigSetName.Text = ((ConfigDS.SetTargetsRow)configDS.SetTargets.Rows[0]).ConfigSetName;
        foreach (var item in configDS.SetTargets)
        {
          clbTargets.Items.Add(item, true);
        }
      }
      else
      {
        btnPullConfig.Enabled = false;
        MessageBox.Show("There no targets in this set to pull the configuration from.", "Empty configuration set", MessageBoxButtons.OK, MessageBoxIcon.Error);
        DialogResult = System.Windows.Forms.DialogResult.Cancel;
        Close();
      }
    }
    #endregion

    #region General staff
    private void DoWorkAnimation(object sender, DoWorkEventArgs e)
    {
      WorkInProgressAnimation L = null;
      _workInProgress_CancelPressed = false;
      DateTime waitStartedAt = DateTime.Now;
      while (true)
      {
        System.Threading.Thread.Sleep(20);
        if (L == null || (DateTime.Now - waitStartedAt).TotalMilliseconds > 200)
        {
          if (L == null)
          {
            L = new WorkInProgressAnimation(_workInProgressText, _workInProgressCaption, _workInProgressSupportCancellation);
            L.SqlCommandToCancel = _workInProgressSqlCommandToCancel;
            L.TopMost = true;
            L.Show();
            L.BringToFront();
            L.Focus();
          }
          else
          {
            L.Text = _workInProgressCaption;
            L.SetLabelText(_workInProgressText);
            L.BringToFront();
            _workInProgress_CancelPressed = L.CancelPressed;
          }

        }
        Application.DoEvents();
        if (_workInProgress.CancellationPending)
        {
          if (L != null) L.Close();
          break;
        }
      }
    }
    #endregion

    #region Private members
    private void PullConfig()
    {
      _workInProgressCaption = "Please wait...";
      _workInProgressText = "Generating script...";
      if (!_workInProgress.IsBusy) _workInProgress.RunWorkerAsync();
      try
      {
        if (cbCreateNewSet.Checked)
        {
          DateTime d = DateTime.Now;
          object o = qTA.CloneConfigSet(_configurationSetID, string.Format("{0}_{1}{2}{3}{4}{5}{6}", tbSelConfigSetName.Text, d.Year, d.Month, d.Day, d.Hour , d.Minute, d.Second));
          _configurationSetID = Convert.ToInt32(o);
        }
        PGTDataSet.ScriptSettingRow _scriptSettings = PGT.Common.SettingsManager.GetCurrentScriptSettings();
        string sepChar = _scriptSettings.CSVSeparator;
        string sExtendedHeader = PGT.Common.Helper.ArrayToString(Enum.GetNames(typeof(InputFileHeader)), sepChar);
        sExtendedHeader += "SetTargetID";
        PGT.ScriptManager _ScriptManager = ScriptingFormManager.OpenNewScriptingForm();
        if (_ScriptManager != null)
        {
          ScriptManagers.Add(_ScriptManager, null);
          _ScriptManager.UpdateHeader(sExtendedHeader.Split(sepChar.ToCharArray(), StringSplitOptions.RemoveEmptyEntries));
          _ScriptManager.OnScriptAborted += _ScriptManager_OnScriptAborted;
          _ScriptManager.OnScriptFinished += _ScriptManager_OnScriptFinished;
          string thisLine = string.Empty;
          _ScriptManager.BeginAddingEntries();
          try
          {
            int lastConfigTargetID = -1;
            foreach (var target in configDS.SetTargets)
            {
              if (IsTargetSelected(target.ConfigTargetID))
              {
                if (lastConfigTargetID == -1) lastConfigTargetID = target.ConfigTargetID;
                // Open a new ScriptinForm if script needs to be generated per configuration target
                if (target.ConfigTargetID != lastConfigTargetID && cbScriptPerHost.Checked)
                {
                  if (_ScriptManager != null)
                  {
                    _ScriptManager.EndAddingEntries();
                    _ScriptManager.ExecuteScript(false);
                  }
                  _ScriptManager = ScriptingFormManager.OpenNewScriptingForm();
                  if (_ScriptManager == null) break;
                  ScriptManagers.Add(_ScriptManager, null);
                  _ScriptManager.UpdateHeader(sExtendedHeader.Split(sepChar.ToCharArray(), StringSplitOptions.RemoveEmptyEntries));
                  _ScriptManager.BeginAddingEntries();
                  lastConfigTargetID = target.ConfigTargetID;
                }
                int configSetTargetID = cbCreateNewSet.Checked ? (int)qTA.GetConfigSetTargetID(_configurationSetID, target.ConfigTargetID) : target.ConfigSetTargetID;
                thisLine = "1," + string.Concat(target.IsJumpServerIPNull() ? "" : target.JumpServerIP.Trim()) + "," + target.DeviceVendor + "," + target.TargetIP + string.Concat(target.IsPortNull() ? "," : string.Format(":{0},", target.Port)) + "" + "," + target.Protocol + "," + "sh run" + ",yes,,,"
                           + ",,," + configSetTargetID;
                if (!string.IsNullOrEmpty(thisLine))
                {
                  bool added = _ScriptManager.AddEntry(thisLine);
                  if (!added)
                  {
                    if (MessageBox.Show("There was an error adding a script line. Do you want to continue ?", "Script generation error", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == System.Windows.Forms.DialogResult.No)
                    {
                      break;
                    }
                  }
                }
              }
            }
          }
          finally
          {
            if (_ScriptManager != null)
            {
              _ScriptManager.EndAddingEntries();
              _ScriptManager.ExecuteScript(false);
            }
          }
        }
      }
      finally
      {
        _workInProgress.CancelAsync();
        _workInProgressSupportCancellation = false;
      }
    }
    private void SaveScriptResults(ScriptManager thisManager)
    {
      int defaultColumnCount = Enum.GetNames(typeof(InputFileHeader)).Length - 1;
      bool errorOccurred = false;

      _workInProgressCaption = "Operation in progress";
      _workInProgressText = "Please wait while saving script results...";
      if (!_workInProgress.IsBusy) _workInProgress.RunWorkerAsync();
      try
      {
        foreach (ScriptListViewItem thisItem in thisManager.GetItems())
        {
          try
          {
            int ConfigSetTargetID = -1;
            if (int.TryParse(thisItem.SubItems[defaultColumnCount].Text, out ConfigSetTargetID))
            {
              // Only save the result if item is selected for execution and result is success !
              if (thisItem.Checked & thisItem.State == ScriptLineState.Success)
              {
                string targetConfig = thisItem.SubItems[(int)LVISubItem.CommandResult].Text;
                if (!string.IsNullOrEmpty(targetConfig))
                {
                  string[] configLines = targetConfig.Split("\r\n".ToCharArray(), StringSplitOptions.RemoveEmptyEntries);
                  SaveConfiguration(configLines, ConfigSetTargetID);
                }
              }
            }
          }
          catch (Exception Ex)
          {
            _workInProgress.CancelAsync();
            MessageBox.Show(string.Format("Item not saved as an unexpected error occurred : {0}", Ex.Message), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            errorOccurred = true;
          }
        }
      }
      finally
      {
        _workInProgress.CancelAsync();
      }
      if (!errorOccurred) thisManager.SetScriptSaved();
    }
    /// <summary>
    /// Saves the passed configuration to database
    /// </summary>
    /// <param name="ConfigurationSetTargetID">If set, configuration lines will be stored/updated for this reference, regardless the currently selected target</param>
    private void SaveConfiguration(string[] configLines, int ConfigurationSetTargetID)
    {
      qTA.DeleteConfiguration(ConfigurationSetTargetID);
      configDS.ConfigLines.Clear();
      foreach (string line in configLines)
      {
        if (line.IndexOf("Building configuration") < 0 & line.IndexOf("Current configuration") < 0)
        {
          ConfigDS.ConfigLinesRow clr = configDS.ConfigLines.NewConfigLinesRow();
          clr.ConfigSetTargetID = ConfigurationSetTargetID;
          clr.ConfigLine = line;
          configDS.ConfigLines.AddConfigLinesRow(clr);
        }
      }
      configLinesTA.Update(configDS);
    }
    private void _ScriptManager_OnScriptFinished(object sender, Common.ScriptEventArgs e)
    {
      Debug.WriteLine("COnfigurationManager : OnScriptFinished");
      if (sender is ScriptManager)
      {
        lock (this) // locking is required to synchronize potential parallel calls
        {
          ScriptManager thisManager = (ScriptManager)sender;
          if (cbAutoSave.Checked || MessageBox.Show(String.Format("Script <{0}> finished. Do you want to auto-save script results to database ?", thisManager.GetScriptName()), "Auto-save", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
          {
            SaveScriptResults(thisManager);
          }
          ScriptManagers.Remove(thisManager);
          thisManager.CloseForm();
        }
      }
    }
    private void _ScriptManager_OnScriptAborted(object sender, Common.ScriptEventArgs e)
    {
      Debug.WriteLine("COnfigurationManager : OnScriptAborted");
      if (sender is ScriptManager)
      {
        lock (this) // locking is required to synchronize potential parallel calls
        {
          ScriptManager thisManager = (ScriptManager)sender;
          //if (cbAutoSave.Checked || MessageBox.Show(String.Format("Script <{0}> finished. Do you want to auto-save script results to database ?", thisManager.GetScriptName()), "Auto-save", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
          //{
          //  SaveScriptResults(thisManager);
          //  RefreshWorkList();
          //}
          ScriptManagers.Remove(thisManager);
        }
      }
    }
    /// <summary>
    /// Indicates whether a target is selected for pulling configuration from
    /// </summary>
    /// <param name="ConfigTargetID">The ConfigTargetID of the target to check</param>
    /// <returns></returns>
    private bool IsTargetSelected(int ConfigTargetID)
    {
      bool result = false;
      foreach (var item in clbTargets.CheckedItems)
      {
        if (((ConfigDS.SetTargetsRow)item).ConfigTargetID == ConfigTargetID)
        {
          result = true;
          break;
        }
      }
      return result;
    }
    #endregion

    #region Event handlers
    private void btnPullconfig_Click(object sender, EventArgs e)
    {
      Hide();
      PullConfig();
      Show();
    }
    private void ConfigPuller_FormClosing(object sender, FormClosingEventArgs e)
    {
      _workInProgressCaption = "Closing form";
      _workInProgressText = "Please wait until all threads are terminated...";
      if (!_workInProgress.IsBusy) _workInProgress.RunWorkerAsync();
      try
      {
        if (ScriptManagers.Count > 0)
        {
          if (MessageBox.Show(string.Format("There are {0} opened Script Executor window(s) open. If you close Scripting Project Manager, the script windows will also be closed and running scripts will be terminated. Do you want to proceed ?", ScriptManagers.Count), "Automated scripting in progress", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == System.Windows.Forms.DialogResult.Yes)
          {
            var managers = ScriptManagers.Keys;
            foreach (ScriptManager thisManager in managers)
            {
              thisManager.OnScriptAborted -= this._ScriptManager_OnScriptAborted;
              thisManager.OnScriptFinished -= this._ScriptManager_OnScriptFinished;
              thisManager.StopScript();
              thisManager.SetScriptSaved();
              thisManager.CloseForm(false);
            }
          }
          else e.Cancel = true;
        }
      }
      finally
      {
        _workInProgress.CancelAsync();
      }
    }
    private void clbTargets_Format(object sender, ListControlConvertEventArgs e)
    {
      if (e.ListItem is ConfigDS.SetTargetsRow) e.Value = ((ConfigDS.SetTargetsRow)e.ListItem).TargetName;
    }
    #endregion


  }
}
