﻿using System;
using System.IO;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using PGT.Common;

namespace PGT.ConfigurationManager
{
  public partial class ConfigTarget : Form
  {
    /// <summary>
    /// Opens a new Config Target Editor dialog.
    /// </summary>
    /// <param name="ConfigTargetID">The ID of the Target to Edit. If empty or set to -1 dialog goes into insert mode</param>
    /// 
    public ConfigTarget(int ConfigTargetID = -1)
    {
      InitializeComponent();
      if (ConfigTargetID != -1) this.configTargetsTableAdapter.FillByConfigTargetID(this.configDS.ConfigTargets, ConfigTargetID);
      else
      {
        ConfigDS.ConfigTargetsRow newRow = this.configDS.ConfigTargets.NewConfigTargetsRow();
        newRow.TargetName = "";
        newRow.TargetIP = "0.0.0.0";
        newRow.DeviceVendor = "Cisco";
        newRow.Protocol = "Telnet";
        this.configDS.ConfigTargets.AddConfigTargetsRow(newRow);
      }
    }
    private void ConfigTarget_Load(object sender, EventArgs e)
    {
      InitLookupLists();
    }
    private void InitLookupLists()
    {
      cbxVendors.DataSource = Common.VendorsManager.SupportedVendors();
      if (!string.IsNullOrEmpty(Properties.Settings.Default.MRUVendor)) cbxVendors.Text = Properties.Settings.Default.MRUVendor;
      if (!string.IsNullOrEmpty(Properties.Settings.Default.MRUProtocol)) cbxProtocols.Text = Properties.Settings.Default.MRUProtocol;
      string configFileName = Helper.GetWorkingDirectory() + "\\" + Common.Properties.Settings.Default.Configfilename;
#if ! Lite
      cbxJumpServers.Items.Clear();
      if (File.Exists(configFileName))
      {
        PGTDataSet pgtDataSet = new PGTDataSet();
        pgtDataSet.ReadXml(configFileName);
        var js = from jumpserver in pgtDataSet.JumpServers
                 where jumpserver.ProfileName == Common.Properties.Settings.Default.ConfigProfileName
                 select jumpserver;
        // we are inserting an empty row to support empty jump server
        PGTDataSet.JumpServersRow emptyRow = pgtDataSet.JumpServers.NewJumpServersRow();
        emptyRow.IPAddress = "";
        emptyRow.HostName = "";
        List<PGTDataSet.JumpServersRow> l = js.ToList();
        l.Insert(0, emptyRow);
        cbxJumpServers.DataSource = l;
      }

      if (!string.IsNullOrEmpty(Properties.Settings.Default.MRUJumpServer)) cbxJumpServers.Text = Properties.Settings.Default.MRUJumpServer;
#endif
    }
    private void btnOK_Click(object sender, EventArgs e)
    {
      ConfigDS.ConfigTargetsRow curRow = (ConfigDS.ConfigTargetsRow)((DataRowView)configTargetsBS.Current).Row;
      if (cbxJumpServers.SelectedValue != null) curRow.JumpServerIP = cbxJumpServers.Text;
      configTargetsBS.EndEdit();
      configTargetsTableAdapter.Update(configDS);
    }
    private void cbxJumpServers_Format(object sender, ListControlConvertEventArgs e)
    {
      string address = ((PGTDataSet.JumpServersRow)e.ListItem).IPAddress;
      string hostname = ((PGTDataSet.JumpServersRow)e.ListItem).HostName;
      if (string.IsNullOrEmpty(hostname)) e.Value = address;
      else e.Value = string.Format("{0} ( {1} )", address, hostname);
    }
  }
}
