﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Data.SqlClient;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Reflection;
using PGT.Common;

namespace PGT.ConfigurationManager
{
  public partial class Deployer : Form
  {
    #region Fields
    /// <summary>
    /// The ID of the configuration set beeing deployed
    /// </summary>
    private int _configurationSetID;
    private BackgroundWorker _workInProgress;
    private string _workInProgressText = "Work in progress...";
    private string _workInProgressCaption = "Please be patient";
    private bool _workInProgress_CancelPressed = false;
    private bool _workInProgressSupportCancellation = false;
    private SqlCommand _workInProgressSqlCommandToCancel = null;
    #endregion

    #region Initialization
    public Deployer(int ConfigurationSetID)
    {
      InitializeComponent();
      _workInProgress = new BackgroundWorker();
      _workInProgress.DoWork += DoWorkAnimation;
      _workInProgress.WorkerSupportsCancellation = true;
      SetControlBackGround(this);
      _configurationSetID = ConfigurationSetID;
    }
    private void SetControlBackGround(Control rootControl)
    {
      if (rootControl != null)
      {
        foreach (Control thisControl in rootControl.Controls)
        {
          if (thisControl is System.Windows.Forms.Label || thisControl is CheckBox || thisControl is GroupBox)
          {
            thisControl.BackColor = System.Drawing.Color.Transparent;
            MethodInfo m = thisControl.GetType().GetMethod("SetStyle");
            if (m != null) m.Invoke(thisControl, new object[] { ControlStyles.SupportsTransparentBackColor, true });
          }
          SetControlBackGround(thisControl);
        }
      }

    }
    private void DrawGradientBackground(object sender, PaintEventArgs e)
    {
      Rectangle rect = (sender as Control).ClientRectangle;
      using (Brush br = new LinearGradientBrush(rect, System.Drawing.Color.White, (sender as Control).BackColor, LinearGradientMode.Vertical))
      {
        e.Graphics.FillRectangle(br, rect);
      }
    }
    private void Deployer_Load(object sender, EventArgs e)
    {
      deployTA.Fill(configDS.Deploy, _configurationSetID);
      if (configDS.Deploy.Rows.Count > 0)
      {
        tbSelConfigSetName.Text = ((ConfigDS.DeployRow)configDS.Deploy.Rows[0]).ConfigSetName;
        setTargetsTA.FillTargetsInSet(configDS.SetTargets, _configurationSetID);
        foreach (var item in configDS.SetTargets)
        {
          clbTargets.Items.Add(item, true);
        }
      }
      else
      {
        btnDeploySet.Enabled = false;
        MessageBox.Show("There is no configuration to deploy in this Set", "Empty configuration", MessageBoxButtons.OK, MessageBoxIcon.Error);
        DialogResult = System.Windows.Forms.DialogResult.Cancel;
      }
    }
    #endregion

    #region Private members
    private void Deploy()
    {
      _workInProgressCaption = "Please wait...";
      _workInProgressText = "Generating script...";
      if (!_workInProgress.IsBusy) _workInProgress.RunWorkerAsync();
      try
      {
        PGTDataSet.ScriptSettingRow _scriptSettings = PGT.Common.SettingsManager.GetCurrentScriptSettings();
        string sepChar = _scriptSettings.CSVSeparator;
        string sExtendedHeader = PGT.Common.Helper.ArrayToString(Enum.GetNames(typeof(InputFileHeader)), sepChar);
        sExtendedHeader += "ConfigLineID";
        PGT.ScriptManager _ScriptManager = ScriptingFormManager.OpenNewScriptingForm();
        if (_ScriptManager != null)
        {
          string thisLine = string.Empty;
          _ScriptManager.BeginAddingEntries();
          try
          {
            int lastConfigTargetID = -1;
            foreach (var configLine in configDS.Deploy)
            {
              if (IsTargetSelected(configLine.ConfigTargetID))
              {
                if (lastConfigTargetID == -1) lastConfigTargetID = configLine.ConfigTargetID;
                // Open a new ScriptinForm if script needs to be generated per configuration target
                if (configLine.ConfigTargetID != lastConfigTargetID && cbScriptPerHost.Checked)
                {
                  if (_ScriptManager != null)
                  {
                    _ScriptManager.EndAddingEntries();
                    _ScriptManager.ExecuteScript(false);
                  }
                  _ScriptManager = ScriptingFormManager.OpenNewScriptingForm();
                  if (_ScriptManager == null) break;
                  _ScriptManager.BeginAddingEntries();
                  lastConfigTargetID = configLine.ConfigTargetID;
                }
                thisLine = "1," + string.Concat(configLine.IsJumpServerIPNull() ? "" : configLine.JumpServerIP.Trim()) + "," + configLine.DeviceVendor + "," + configLine.TargetIP + string.Concat(configLine.IsPortNull() ? "," : string.Format(":{0},", configLine.Port)) + "" + "," + configLine.Protocol + "," + configLine.ConfigLine + ",yes,,,"
                           + ",,,," + configLine.ConfigLineID;
                if (!string.IsNullOrEmpty(thisLine))
                {
                  bool added = _ScriptManager.AddEntry(thisLine);
                  if (!added)
                  {
                    if (MessageBox.Show("There was an error adding a script line. Do you want to continue ?", "Script generation error", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == System.Windows.Forms.DialogResult.No)
                    {
                      break;
                    }
                  }
                }
              }
            }
          }
          finally
          {
            if (_ScriptManager != null)
            {
              _ScriptManager.EndAddingEntries();
              _ScriptManager.ExecuteScript(false);
            }
          }
        }
      }
      finally
      {
        _workInProgress.CancelAsync();
        _workInProgressSupportCancellation = false;
      }
    }
    private bool IsTargetSelected(int ConfigTargetID)
    {
      bool result = false;
      foreach (var item in clbTargets.CheckedItems)
      {
        if (((ConfigDS.SetTargetsRow)item).ConfigTargetID == ConfigTargetID)
        {
          result = true;
          break;
        }
      }
      return result;
    }

    private void DoWorkAnimation(object sender, DoWorkEventArgs e)
    {
      WorkInProgressAnimation L = null;
      _workInProgress_CancelPressed = false;
      DateTime waitStartedAt = DateTime.Now;
      while (true)
      {
        System.Threading.Thread.Sleep(20);
        if (L == null || (DateTime.Now - waitStartedAt).TotalMilliseconds > 200)
        {
          if (L == null)
          {
            L = new WorkInProgressAnimation(_workInProgressText, _workInProgressCaption, _workInProgressSupportCancellation);
            L.SqlCommandToCancel = _workInProgressSqlCommandToCancel;
            L.TopMost = true;
            L.Show();
            L.BringToFront();
            L.Focus();
          }
          else
          {
            L.Text = _workInProgressCaption;
            L.SetLabelText(_workInProgressText);
            L.BringToFront();
            _workInProgress_CancelPressed = L.CancelPressed;
          }

        }
        Application.DoEvents();
        if (_workInProgress.CancellationPending)
        {
          if (L != null) L.Close();
          break;
        }
      }
    }
    #endregion

    #region Event handlers
    private void btnDeploySet_Click(object sender, EventArgs e)
    {
      Hide();
      Deploy();
      DialogResult = System.Windows.Forms.DialogResult.OK;
      Close();
    }
    private void clbTargets_Format(object sender, ListControlConvertEventArgs e)
    {
      if (e.ListItem is ConfigDS.SetTargetsRow) e.Value = ((ConfigDS.SetTargetsRow)e.ListItem).TargetName;
    }
    #endregion

  }
}
