﻿/*
 Copyright (c) 2014-2015 Laszlo Frank, All Rights Reserved.
 This is a Pretty Good Terminal demo file showing the usage of a custom action handler.
 available in the Professional Edition of the software.

 *                                 !!!!!!
 * Please note, that the contents of this file is for demo purposes only
 * and intended to show PGT functionality. As a result, the code itself
 * may not be complete or functional from the networking device's perspective.
 * 

*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Net;
using PGT.ExtensionInterfaces;
using System.Windows.Forms;

namespace PGTDemo
{
  class RNTCustomActionHandler : ICustomActionHandler
  {
    private List<string> checkedhosts;
    public void Initialize(IScriptExecutorBase Executor)
    {
      checkedhosts = new List<string>(10);
    }
    public bool DoCustomAction(IScriptExecutorBase Executor, DeviceConnectionInfo ci, out string ActionResult, out bool ConnectionDropped, out bool BreakExecution)
    {
      // ***************************************************************************************
      // Check router configuration and create a change script based on the current setings.
      // The created change script can be loaded to PGT later for execution
      // ***************************************************************************************
      checkedhosts.Add(ci.DeviceIP);
      bool result = false;
      bool timedout = false;
      BreakExecution = false;
      ConnectionDropped = false;
      ActionResult = "CustomActionID was not handled";
      if ((ci.CustomActionID == "RNT_1") | (ci.CustomActionID == "RNT_2"))
      {
        #region Config script creation

        // action IDs are :
        //   RNT_1 : log healthcek information
        //	 RNT_2 : create configuration script
        //
        string detectedHostName = Executor.STerminal.GetHostName("#");
        bool continuescript = true;
        if (detectedHostName.ToUpperInvariant().Trim() != ci.HostName.ToUpperInvariant().Trim())
        {
          switch (ci.CustomActionID)
          {
            case "RNT_1":
              {
                Executor.ShowActivity(string.Format("WRONG host name ! Should be on <{0}> but we are on <{1}>.", ci.HostName, detectedHostName));
                break;
              }
            case "RNT_2":
              {
                ActionResult = string.Format("ALERT : WE ARE ON THE WRONG HOST ! Should be on <{0}> but we are on <{1}>. Custom actions skipped.", ci.HostName, detectedHostName);
                continuescript = false;
                break;
              }
          }
        }
        if (continuescript)
        {
          try
          {
            Executor.ShowActivity(string.Format(">> We are on host : {0}", detectedHostName));
            List<string> ConfigScript = new List<string>(20);
            if (ci.CustomActionID == "RNT_2") Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "", "yes", "", "", "reloadschedule 30"), false);
            ConfigScript.Add("conf t");

            #region VPN ID check
            string command = "sh run | in router bgp";
            Executor.ShowActivity(command);
            string commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            int h_VPNID = commandResult.IndexOf("6100") >= 0 ? 11 : commandResult.IndexOf("6200") >= 0 ? 10 : -1;
            #endregion

            ConfigScript.Add("interface Dialer 2");

            #region dialer idle-timeout
            command = "sh run int dialer 2 | inc dialer idle-timeout";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            int v_IdleTimeout = commandResult.IndexOf("900") >= 0 ? 900 : commandResult.IndexOf("180") >= 0 ? 180 : -1;
            switch (v_IdleTimeout)
            {
              case 900:
                {
                  ConfigScript.Add("  dialer idle-timeout 180");
                  break;
                }
            }

            #endregion

            #region get dialer bandwidth
            command = "sh run int dialer 2 | inc bandwidth";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            int v_Bandwidth = commandResult.IndexOf("64") >= 0 ? 64 : commandResult.IndexOf("128") >= 0 ? 128 : -1;
            #endregion

            #region dialer load-threshold check
            command = "sh run int dialer 2 | inc load-threshold";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_loadthreshold_exists = commandResult.IndexOf("dialer load-threshold") >= 0;
            bool h_loadthreshold_ok = ((v_Bandwidth == 64) & !b_loadthreshold_exists) | ((v_Bandwidth == 128) & b_loadthreshold_exists);
            if (!h_loadthreshold_ok)
            {
              switch (v_Bandwidth)
              {
                case 64:
                  {
                    if (b_loadthreshold_exists) ConfigScript.Add("  no dialer load-threshold 100 either");
                    break;
                  }
                case 128:
                  {
                    if (!b_loadthreshold_exists) ConfigScript.Add("  dialer load-threshold 100 either");
                    break;
                  }
              }
            }
            #endregion

            #region dialer ppp multilink links max check
            command = "sh run int dialer 2 | inc ppp multilink links max";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            int h_pppmultilink_count = commandResult.IndexOf("ppp multilink links maximum 1") >= 0 ? 1 : commandResult.IndexOf("ppp multilink links maximum 2") >= 0 ? 2 : 0;
            bool h_pppmultilink_ok = ((v_Bandwidth == 64) & (h_pppmultilink_count == 1)) | ((v_Bandwidth == 128) & (h_pppmultilink_count == 2));
            if (!h_pppmultilink_ok)
            {
              switch (v_Bandwidth)
              {
                case 64:
                  {
                    if (h_pppmultilink_count != 1) ConfigScript.Add("  ppp multilink links maximum 1");
                    break;
                  }
                case 128:
                  {
                    if (h_pppmultilink_count != 2) ConfigScript.Add("  ppp multilink links maximum 2");
                    break;
                  }
              }
            }
            #endregion

            ConfigScript.Add("exit"); // from interface Dialer 1
            ConfigScript.Add("!");

            #region  route tag check
            command = "sh run | in ip route";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_tagged = (commandResult.IndexOf("tag 100") >= 0) | (commandResult.IndexOf("tag 105") >= 0);
            #endregion

            #region  STATIC2RIP check
            command = "sh run | in redistribute static route-map STATIC2RIP";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_rip_redist_exists = commandResult.IndexOf("redistribute static route-map STATIC2RIP") >= 0;
            bool h_rip_ok = !(b_rip_redist_exists ^ b_tagged);
            if (!h_rip_ok)
            {
              ConfigScript.Add("router rip");
              if (b_tagged) ConfigScript.Add("  redistribute static route-map STATIC2RIP");
              else ConfigScript.Add("  no redistribute static");
              ConfigScript.Add("exit");
              ConfigScript.Add("!");
            }
            #endregion

            #region  STATIC2BGP check
            command = "sh run | in redistribute static route-map STATIC2BGP";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_bgp_redist_exists = commandResult.IndexOf("redistribute static route-map STATIC2BGP") >= 0;
            bool h_bgp_ok = !(b_bgp_redist_exists ^ b_tagged);
            if (!h_bgp_ok)
            {
              switch (h_VPNID)
              {
                case 10:
                  {
                    ConfigScript.Add("router bgp 6100");
                    break;
                  }
                case 11:
                  {
                    ConfigScript.Add("router bgp 6200");
                    break;
                  }
              }
              if (b_tagged) ConfigScript.Add("  redistribute static route-map STATIC2BGP");
              else ConfigScript.Add("  no redistribute static");
              ConfigScript.Add("exit");
              ConfigScript.Add("!");
            }
            #endregion

            #region  access-list 121 check

            // access-list 121 check 1
            command = "sh ip access-list 121 | i permit a.b.c.d";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_acl21_18dot9 = commandResult.IndexOf("permit a.b.c.d") >= 0;

            // access-list 121 check 2
            command = "sh ip access-list 121 | i permit a.b.c.d";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_acl21_18dot4 = commandResult.IndexOf("permit a.b.c.d") >= 0;


            // access-list 121 check 3
            command = "sh ip access-list 121 | i permit a.b.c.d";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_acl21_50dot9 = commandResult.IndexOf("permit a.b.c.d") >= 0;


            // access-list 121 check 4
            command = "sh ip access-list 121 | i permit a.b.c.d";
            Executor.ShowActivity(command);
            commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
            Executor.ShowActivity(commandResult);
            bool b_acl21_50dot4 = commandResult.IndexOf("permit a.b.c.d") >= 0;

            if (!b_acl21_50dot4 | !b_acl21_50dot9 | b_acl21_18dot4 | b_acl21_18dot9)
            {
              ConfigScript.Add("no access-list 121");
              ConfigScript.Add("access-list 121 remark SNMP Access");
              ConfigScript.Add("access-list 121 permit a.b.c.d");
              ConfigScript.Add("access-list 121 permit a.b.c.d");
              ConfigScript.Add("access-list 121 permit a.b.c.d");
              ConfigScript.Add("access-list 121 permit a.b.c.d");
              ConfigScript.Add("access-list 121 deny   any log");
            }


            #endregion

            // Do not cancel reload now, first we must log back on, then we can cancel the scheduled reload request

            #region Log results	depending on ConnectionInfo.CustomActionID
            switch (ci.CustomActionID)
            {
              case "RNT_1":
                {
                  Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10},{11},{12},{13},{14},{15},{16},{17}", ci.DeviceIP, h_VPNID, v_IdleTimeout,
                    v_Bandwidth, h_loadthreshold_ok, h_pppmultilink_ok, h_rip_ok, h_bgp_ok, b_acl21_50dot4, b_acl21_50dot9, b_acl21_18dot4, b_acl21_18dot9, true,
                    true, true, true, true, true), false);
                  break;
                }
              case "RNT_2":
                {
                  foreach (string configLine in ConfigScript)
                  {
                    //Selected, JumpServerList, Vendor, ConnectionInfo.DeviceIP, HostName, ConnectionProtocol, Command, PrivilegedModeRequired, ReconnectRequired, RegExSearch, ConnectionInfo.CustomActionID
                    Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", configLine, "yes", "", "", ""), false);
                  }
                  break;
                }
            }

            #endregion

            if (ci.CustomActionID == "RNT_2")
            {

              #region Add banner
              ConfigScript.Clear();
              ConfigScript.Add("banner exec ^C");
              ConfigScript.Add("                            Secure Device Access");
              ConfigScript.Add("");
              ConfigScript.Add("    If you are not authorised to access this device then please log off now.");
              ConfigScript.Add(" *** ALL Commands from this device are Authorised & Authenticated & Accounted ***");
              ConfigScript.Add("");
              ConfigScript.Add("      Router Template X");
              ConfigScript.Add("^C");
              ConfigScript.Add("banner motd ^C");
              ConfigScript.Add("");
              ConfigScript.Add("                   ");
              ConfigScript.Add("");
              ConfigScript.Add("     !! WARNING : You have accessed a Computer system operated by Company !!");
              ConfigScript.Add("");
              ConfigScript.Add("  You are required to have a personal authorisation from the System");
              ConfigScript.Add("");
              ConfigScript.Add("  Administrator before you use this system and you are strictly limited");
              ConfigScript.Add("");
              ConfigScript.Add("  to the use set out in that written authorisation. Unauthorised access");
              ConfigScript.Add("");
              ConfigScript.Add("  of a computer constitutes an offence under the Computer Misuse Act 1990.");
              ConfigScript.Add("");
              ConfigScript.Add("  You must ensure your User password conforms to the guidelines specified");
              ConfigScript.Add("");
              ConfigScript.Add("  in the Company Computer Security Manual.");
              ConfigScript.Add("");
              ConfigScript.Add("  If you understand this message and have been authorised to use this");
              ConfigScript.Add("");
              ConfigScript.Add("  system please enter your username and password below to continue this");
              ConfigScript.Add("");
              ConfigScript.Add("  session.");
              ConfigScript.Add("");
              ConfigScript.Add("        Otherwise you must disconnect from this session immediately.");
              ConfigScript.Add("");
              ConfigScript.Add("");
              ConfigScript.Add("");
              ConfigScript.Add("                         Secure Device Access");
              ConfigScript.Add("");
              ConfigScript.Add("*** ALL Commands from this device are Authorised & Authenticated & Accounted ***");
              ConfigScript.Add("");
              ConfigScript.Add("");
              ConfigScript.Add("^C");
              ConfigScript.Add("!");
              #endregion
              // for banner, we need to control command execution with the NOWAIT CustomActionID
              foreach (string configLine in ConfigScript)
              {
                //Selected, JumpServerList, Vendor, ConnectionInfo.DeviceIP, HostName, ConnectionProtocol, Command, PrivilegedModeRequired, ReconnectRequired, RegExSearch, ConnectionInfo.CustomActionID
                Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", configLine, "yes", "", "", "NOWAIT;NOTRIM"), false);
              }
              // exit from config mode
              Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "exit", "yes", "", "", ""), false);
              // at the end, we need to quit and reconnect to the router	and so we can cancel reload and write configuration only after a successful reconnection
              // Selected, JumpServerList, Vendor, ConnectionInfo.DeviceIP, HostName, ConnectionProtocol, Command, PrivilegedModeRequired, ReconnectRequired, RegExSearch, ConnectionInfo.CustomActionID
              Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "reload cancel", "yes", "yes", "", ""), false);
              Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "write", "yes", "", "", ""), false);
            }
            ActionResult = "Custom action COMPLETED";
            result = true;
          }
          catch (Exception Ex)
          {
            ActionResult = Ex.Message;
          }
        }
        #endregion
      }
      else if (ci.CustomActionID == "RNT_3")
      {
        #region Update ALCs unconditionally according to template
        List<string> ConfigScript = new List<string>(20);

        #region VPN ID check
        string command = "sh run | in router bgp";
        Executor.ShowActivity(command);
        string commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
        Executor.ShowActivity(commandResult);
        int h_VPNID = commandResult.IndexOf("6100") >= 0 ? 11 : commandResult.IndexOf("6200") >= 0 ? 10 : -1;
        #endregion

        ConfigScript.Add("conf t");

        #region  recreate access-list 21

        ConfigScript.Add("no access-list 121");
        ConfigScript.Add("access-list 121 remark SNMP Access");
        ConfigScript.Add("access-list 121 permit a.b.c.d");
        ConfigScript.Add("access-list 121 permit a.b.c.d");
        ConfigScript.Add("access-list 121 permit a.b.c.d");
        ConfigScript.Add("access-list 121 deny   any log");
        ConfigScript.Add("!");


        #endregion

        ConfigScript.Add("exit");
        ConfigScript.Add("write");


        foreach (string configLine in ConfigScript)
        {
          //Selected, JumpServerList, Vendor, ConnectionInfo.DeviceIP, HostName, ConnectionProtocol, Command, PrivilegedModeRequired, ReconnectRequired, RegExSearch, ConnectionInfo.CustomActionID
          Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", configLine, "yes", "", "", ""), false);
        }
        ActionResult = "Custom action COMPLETED";
        result = true;

        #endregion
      }
      else if (ci.CustomActionID == "RNT_BannerCheck")
      {
        #region This action will check whether the template version is V20 or different.
        string command = "sh run | in Router Template";
        string commandResult = Executor.STerminal.ExecCommand(command, "#", out timedout);
        if (!timedout)
        {
          if (!string.IsNullOrEmpty(commandResult))
          {
            string[] words = commandResult.ToLowerInvariant().Split(" ".ToCharArray(), StringSplitOptions.RemoveEmptyEntries);
            if (words.Length >= 4)
            {
              if (words[2].StartsWith("rnet"))
              {
                string templateVersion = words[3].Replace("\r\n", "");
                if (templateVersion == "v20")
                {
                  ActionResult = "Template verison OK";
                  result = true;
                }
                else
                {
                  ActionResult = string.Format("Router must be updated, current version is : {0}", templateVersion);
                  result = false;
                }
              }
              else Executor.ShowActivity(string.Format("Error : suspicious command output at words[2] : {0}", words[2]));
            }
            else Executor.ShowActivity(string.Format("Error : unexpected command output : {0}", commandResult));
          }
          else Executor.ShowActivity(string.Format("Error : no response to command : {0}", command));
        }
        else Executor.ShowActivity("Error : command timed out : {0}");
        #endregion
      }
      else if (ci.CustomActionID == "RNT_BannerUpdate")
      {
        #region This action item will generate the script required to update only the banner text
        List<string> ConfigScript = new List<string>(20);
        ConfigScript.Add("banner exec ^C");
        ConfigScript.Add("                            Secure Device Access");
        ConfigScript.Add("");
        ConfigScript.Add("    If you are not authorised to access this device then please log off now.");
        ConfigScript.Add(" *** ALL Commands from this device are Authorised & Authenticated & Accounted ***");
        ConfigScript.Add("");
        ConfigScript.Add("      Router Template Y");
        ConfigScript.Add("^C");
        ConfigScript.Add("banner motd ^C");
        ConfigScript.Add("");
        ConfigScript.Add("");
        ConfigScript.Add("     !! WARNING : You have accessed a Computer system operated by Company !!");
        ConfigScript.Add("");
        ConfigScript.Add("  You are required to have a personal authorisation from the System");
        ConfigScript.Add("");
        ConfigScript.Add("  Administrator before you use this system and you are strictly limited");
        ConfigScript.Add("");
        ConfigScript.Add("  to the use set out in that written authorisation. Unauthorised access");
        ConfigScript.Add("");
        ConfigScript.Add("  of a computer constitutes an offence under the Computer Misuse Act 1990.");
        ConfigScript.Add("");
        ConfigScript.Add("  You must ensure your User password conforms to the guidelines specified");
        ConfigScript.Add("");
        ConfigScript.Add("  in the Company Computer Security Manual.");
        ConfigScript.Add("");
        ConfigScript.Add("  If you understand this message and have been authorised to use this");
        ConfigScript.Add("");
        ConfigScript.Add("  system please enter your username and password below to continue this");
        ConfigScript.Add("");
        ConfigScript.Add("  session.");
        ConfigScript.Add("");
        ConfigScript.Add("        Otherwise you must disconnect from this session immediately.");
        ConfigScript.Add("");
        ConfigScript.Add("");
        ConfigScript.Add("");
        ConfigScript.Add("                         Secure Device Access");
        ConfigScript.Add("");
        ConfigScript.Add("*** ALL Commands from this device are Authorised & Authenticated & Accounted ***");
        ConfigScript.Add("");
        ConfigScript.Add("");
        ConfigScript.Add("^C");
        ConfigScript.Add("!");
        // save the commands to file
        Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "conf t", "yes", "", "", ""), false);
        foreach (string configLine in ConfigScript)
        {
          //Selected, JumpServerList, Vendor, ConnectionInfo.DeviceIP, HostName, ConnectionProtocol, Command, PrivilegedModeRequired, ReconnectRequired, RegExSearch, ConnectionInfo.CustomActionID
          Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", configLine, "yes", "", "", "NOWAIT;NOTRIM"), false);
        }

        Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "exit", "yes", "", "", ""), false);
        Executor.WriteLogEntryEx(string.Format("{0},{1},{2},{3},{4},{5},{6},{7},{8},{9},{10}", "1", ci.JumpList, "cisco", ci.DeviceIP, ci.HostName, "telnet", "write", "yes", "", "", ""), false);
        ActionResult = "Custom action completed";
        result = true;
        #endregion
      }
      return result;
    }
    public void HostUnreachable(IScriptExecutorBase Executor, DeviceConnectionInfo ci)
    {
      Executor.WriteLogEntryEx(string.Format("{0},{1},{2}", ci.HostName, ci.DeviceIP, "Host is unreachable"));
    }
    public void Finalize()
    {
    }
    public bool LoggingRequired()
    {
      return true;
    }
    public string[] HandledCustomActions()
    {
      return new string[] { "RNT_1", "RNT_2", "RNT_3", "RNT_BannerCheck", "RNT_BannerUpdate" };
    }
  }
  class RNTCustomMenuHandler : ICustomMenuHandler
  {
    #region Fields
    private Form AppMainForm;
    #endregion
    #region ICustomMenuHandler Members

    public ToolStripMenuItem GetMenu()
    {
      ToolStripMenuItem tsmMainMenu = new ToolStripMenuItem();
      #region Menu definition
      // 
      // tsmSQLInterfaceMainMenu
      // 
      /*tsmMainMenu.Image = PGTDemo.Resource1.color_wheel_16xLG;*/
      tsmMainMenu.ImageTransparentColor = System.Drawing.Color.Black;
      tsmMainMenu.Name = "PGTDemo.tsmMainMenu";
      tsmMainMenu.Text = "Demo Manager";
      tsmMainMenu.Click += tsmMainMenu_Click;

      #endregion
      return tsmMainMenu;
    }

    private void tsmMainMenu_Click(object sender, EventArgs e)
    {
      // Do here want you want
    }

    public void SetMainForm(Form mainForm)
    {
      AppMainForm = mainForm;
    }

    #endregion
  }
}
