##############################################################
#                                                            #
#  This sample script shows how to collect data from a Cisco #
#  router and interact with PGT by sending back results      #
#  and indicating script success.                            #
#                                                            #
#  The script will collect DSL statistics from               #
#  Cisco  857 or 867VAE routers.                             #
#                                                            #
#  Compatible with PGT v6.2                                  #
#                                                            #
#  Copyright Laszlo Frank (c) 2016                           #
#                                                            #
##############################################################

import re

def GetHWVersion():
  commandResult = Session.ExecCommand("sh version")
  _versions = [ n.strip(" ") for n in commandResult.splitlines() if n.startswith("Cisco") ]
  HWVersionInfo = [ v for v in _versions[1].strip(" ").split(" ")]
  HWPlatform = HWVersionInfo[1]
  return HWPlatform

#Define the list we will later use for filtering
InterestingLines = []
#Get router HW version
rVersion = GetHWVersion()
rCommand = ""
#Based on the router version set rCommand and InterestingLines variables
if rVersion == "857" : 
  rCommand = "sh dsl interface atm 0"
  #List the line beginnings we are interested in
  InterestingLines = ["Attenuation","Noise Margin","Attainable Rate","Actual Power","Capacity Used","Defect status","Last Fail Code","Modem FW Version","Modem PHY Version","Operation FW","Init FW"]
  
elif rVersion == "867VAE-K9" or rVersion == "867VAE" or rVersion == "877" : 
  rCommand = "sh controllers vdsl 0"
  #List the line beginnings we are interested in
  InterestingLines = ["Attenuation","Noise Margin","Attainable Rate","Actual Power","Capacity Used","Defect status","Last Fail Code","Modem FW Version","Modem PHY Version","Operation FW","Init FW"]

if rCommand != "": 
  DSLResult = Session.ExecCommand(rCommand)
  if len(DSLResult) > 0 :
    DSLDataLines = map(lambda pattern:re.findall("(" + pattern +".+)\r", DSLResult), InterestingLines)
    ActionResult = ";".join([",".join(l) for l in DSLDataLines])  
    ScriptSuccess = True
  else:
    ActionResult = "Did not get vdsl controller data"
    ScriptSuccess = False
else:
  ActionResult = "Router HW not supported"
  ScriptSuccess = False  