##############################################################
#                                                            #
#  This sample script shows how to collect data from a Cisco #
#  router and interact with PGT by sending beck results      #
#  and indicating script success                             #
#                                                            #
#  Compatible with PGT v6.2                                  #
#                                                            #
#  Copyright Laszlo Frank (c) 2016                           #
#                                                            #
##############################################################

import re
import sys

def GetVersion():
  commandResult = Session.ExecCommand("sh version")
  _versions = [ n.strip(" ") for n in commandResult.splitlines() if n.startswith("Cisco") ]
  CiscoVersionInfo = [ v.strip(" ")  for v in _versions[0].split(",")]
  #Calculate IOS version numbers. This is more for demonstration, some scripts may need to check version numbers seperately
  _IOSVersion = CiscoVersionInfo[2]
  _IOSVersionNumber = _IOSVersion.split(" ")[1]
  _IOSSubVersionNumbers = re.findall(r"[\w']+", _IOSVersionNumber)
  IOSMajorRelease = _IOSSubVersionNumbers[0]
  IOSMinorRelease = _IOSSubVersionNumbers[1]
  IOSMaintenanceNumber = _IOSSubVersionNumbers[2]
  IOSTrainID = _IOSSubVersionNumbers[3]
  # Calculate Router HW version
  HWVersionInfo = [ v for v in _versions[1].strip(" ").split(" ")]
  HWPlatform = HWVersionInfo[0] + " " + HWVersionInfo[1]
  
  return "IOS Version:" + IOSMajorRelease + "." + IOSMinorRelease + "." + IOSMaintenanceNumber + "." +  IOSTrainID + ";HW:" + HWPlatform
    
def GetGW():
  # The VLAN number to search the if address
  GWVlan = 1
  # Check if VLAN2 exists
  commandResult = Session.ExecCommand("sh vlan-switch id 2")
  if commandResult.find("VLAN0002") >= 0 : GWVlan = 2

  commandResult = Session.ExecCommand("sh run int vlan{0}".format(GWVlan))

  IpAddress = ""
  SubnetMask = ""
  #Get VLAN1 interface details
  for thisLine in commandResult.splitlines():
    if thisLine.strip(" ").startswith("ip address"):
      words = thisLine.strip(" ").split(" ")
      if len(words) > 3 :
        IpAddress = words[2]
        SubnetMask = words[3]
        break
                  
  return "Gateway is : IP {0}/{1} on VLAN {2}".format(IpAddress,SubnetMask,GWVlan)
    
def GetHostName():
  return  "Hostname: " + Session.GetHostName("#")

def GetDomainName():
  # Check for domain name
  commandResult = Session.ExecCommand("sh ip domain-name")
  return "Domain name is : {0}".format(commandResult.replace("\r\n",""))
  
def GetSSHVersion():
  # Check for ssh version
  commandResult = Session.ExecCommand("sh ip ssh")
  sshres = commandResult.splitlines()
  return "SSH state is : {0}".format(sshres[0].replace("\r\n",""))
  
def GetUptime():
  # Check for domain name
  commandResult = Session.ExecCommand("sh ver | i uptime")
  return commandResult.replace("\r\n","")
   
try:
  ActionResult = ";".join([GetHostName(), GetVersion(), GetGW(), GetDomainName(), GetSSHVersion(), GetUptime()])
  ScriptSuccess = True
except:
  ActionResult = "Script error : {0}".format(sys.exc_info()[1])
  ScriptSuccess = False  