##############################################################
#                                                            #
#  This sample script shows how to use PGT ScriptableTerinal #
#  class for low level connection management bypassing       #
#  PGT scripting engine.                                     #
#                                                            #
#  You would run such a script directly fomr Python          #
#  leveraging PGT connection servecies.                      #
#                                                            #
#  Compatible with PGT 6.2 or later                          #
#                                                            #
#  Copyright Laszlo Frank (c) 2016                           #
#                                                            #
##############################################################

import sys
import clr
clr.AddReferenceToFileAndPath("C:\\My Projects\\Visual Studio Projects\\PrettyGoodTerminal\\bin\\PGTInterfaces.dll")
import PGT.ExtensionInterfaces

connect_success = PGT.ExtensionInterfaces.LogonResult.Success

# You can use the ConnectionParameters strutcure to define parameters for connection
CD = PGT.ExtensionInterfaces.ConnectionParameters()
CD.DeviceIP = "10.10.10.2"
CD.Protocol = PGT.ExtensionInterfaces.ConnectionProtocol.Telnet
CD.DeviceVendor = "Cisco"
CD.LogonUserName = "Cisco"
CD.LogonPassword = "cisco"
CD.EnablePassword = "cisco"

# Disconnect if already connected
if Session.IsConnected: 
  Session.Disconnect()

# If you does not want to use ConnetionParameters structure, you could call connect this way :
#connResult = Session.LogonToHost("Telnet", "10.10.10.2", "Cisco", "cisco", "", "", "Cisco")

#----------------------------------------------------------------------------------------------------------------------
# The Terminal object has both Connect() and LogonToHost() functions.
# While Connect() can only connect to a directly reachable host (over a routed connection),
# LogonToHost() can use an existing terminal session to log on to a remnote host by scripting the terminal connection, 
# using the existing connection as a jump server. As a result, LogonToHost() could be called several times
# for each hop. This behaviour is, however, better managed by ConnectoJumpServers() function.
#----------------------------------------------------------------------------------------------------------------------

connResult = Session.LogonToHost(CD)

# The returned value is a Tuple(LogonResultEx, Bool), where the Bool value represents if 
# privileged mode on router was successfully invoked or not.
# LogonResultEx reflects the result of the logon operation.
# LogonResultEx.lResult stands for the result, while LogonResultEx.Message is the text message related to lResult

# If you connected using the sencond approach - without ConnectionParameters - the returned value
# was not a Tuple, but a LogonResultEx, sou you would need to check for success like:
#if connResult.lResult == connect_success:

if connResult[0].lResult == connect_success:
  try:
    result = Session.ExecCommand("sh version")
#Session.ExecCommand("sh version", "#") could also be used  to specify the prompt to wait for ("#" in this case)
#If prompt is not specified, PGT determines the current prompt from vendor information and whether currently in
#privileged mode or not. If EnablePassword was supplied, PGT assumes the router is in elevated privilege mode.
    for line in result.splitlines(): 
      print line
  except:
    excInfo = sys.exc_info()
    print "Script error : {0}".format(excInfo[1])    
else:
  print connResult[0].Message